@@ -37,10 +37,11 @@ class AlgoLogger:
         self.output()
 
     def set_name(self, name):
-        self.error_print = " [ {0:<15} -------- ERROR --------  ] ".format(name)
-        self.trade_print = " [ {0:<15} -------- TRADE --------  ] ".format(name)
-        self.info_print =  " [ {0:<15} -------- INFO  --------  ] ".format(name)
-        self.warn_print =  " [ {0:<15} -------- WARN  --------  ] ".format(name)
+        
+        self.error_print = " [ {} {} ][ -------- ERROR -------- ] ".format(name, datetime.now().replace(microsecond=0))
+        self.trade_print = " [ {} {} ][ -------- TRADE -------- ] ".format(name, datetime.now().replace(microsecond=0))
+        self.info_print =  " [ {} {} ][ -------- INFO  -------- ] ".format(name, datetime.now().replace(microsecond=0))
+        self.warn_print =  " [ {} {} ][ -------- WARN  -------- ] ".format(name, datetime.now().replace(microsecond=0))
 
     def output(self):
         for p in self.to_print:
@@ -330,12 +331,15 @@ class Stream:
                 self.open_orders[id] = (side, qty, limit_price, symbol)
                 log.info("New Order - {}  {}  {}, # still open: {}".format(id, symbol, side, len(self.open_orders)))
             elif trade.event == 'canceled':
+                id = trade.order['id']
                 del self.open_orders[trade.order['id']]
                 log.info("Canceled Order - {}, # still open: {}".format(id, len(self.open_orders)))
             elif trade.event == 'fill':
+                id = trade.order['id']
                 del self.open_orders[trade.order['id']]
                 log.info("Filled Order - {}, # still open: {}".format(id, len(self.open_orders)))
             elif trade.event == 'expired':
+                id = trade.order['id']
                 del self.open_orders[trade.order['id']]
                 log.info("Expired Order - {}, # still open: {}".format(id, len(self.open_orders)))
 
